@@ -1,16 +1,17 @@
 package Geo::IP;
 
 use strict;
-use vars qw(@ISA $VERSION @EXPORT);
+use base qw(DynaLoader Exporter);
+use vars qw($VERSION @EXPORT);
+
+
+BEGIN {
+       $VERSION = '1.27';
+       bootstrap Geo::IP $VERSION;
+}
 
 require Geo::IP::Record;
-require DynaLoader;
-require Exporter;
-@ISA = qw(DynaLoader Exporter);
 
-$VERSION = '1.26';
-
-bootstrap Geo::IP $VERSION;
 
 sub GEOIP_STANDARD(){0;}
 sub GEOIP_MEMORY_CACHE(){1;}
@@ -22,8 +23,23 @@ sub GEOIP_DIALUP_SPEED(){1;}
 sub GEOIP_CABLEDSL_SPEED(){2;}
 sub GEOIP_CORPORATE_SPEED(){3;}
 
+sub GEOIP_COUNTRY_EDITION(){1;}
+sub GEOIP_REGION_EDITION_REV0(){7;}
+sub GEOIP_CITY_EDITION_REV0(){6;}
+sub GEOIP_ORG_EDITION(){5;}
+sub GEOIP_ISP_EDITION(){4;}
+sub GEOIP_CITY_EDITION_REV1(){2;}
+sub GEOIP_REGION_EDITION_REV1(){3;}
+sub GEOIP_PROXY_EDITION(){8;}
+sub GEOIP_ASNUM_EDITION(){9;}
+sub GEOIP_NETSPEED_EDITION(){10;}
+
+
 @EXPORT = qw( GEOIP_STANDARD GEOIP_MEMORY_CACHE GEOIP_CHECK_CACHE GEOIP_INDEX_CACHE
-	GEOIP_UNKNOWN_SPEED GEOIP_DIALUP_SPEED GEOIP_CABLEDSL_SPEED GEOIP_CORPORATE_SPEED );
+	GEOIP_UNKNOWN_SPEED GEOIP_DIALUP_SPEED GEOIP_CABLEDSL_SPEED GEOIP_CORPORATE_SPEED 
+	GEOIP_COUNTRY_EDITION GEOIP_REGION_EDITION_REV0 GEOIP_CITY_EDITION_REV0 
+	GEOIP_ORG_EDITION GEOIP_ISP_EDITION GEOIP_CITY_EDITION_REV1 GEOIP_REGION_EDITION_REV1
+	GEOIP_PROXY_EDITION GEOIP_ASNUM_EDITION GEOIP_NETSPEED_EDITION);
 
 1;
 __END__
@@ -90,6 +106,16 @@ cache you can force a reload if the file is updated by setting GEOIP_CHECK_CACHE
 
 Constructs a new Geo::IP object with the database located at C<$database_filename>.
 
+=item $gi = Geo::IP->open_type( $database_type, $flags );
+
+Constructs a new Geo::IP object with the $database_type database located in the standard
+location.  For example
+
+  $gi = Geo::IP->open_type( GEOIP_CITY_EDITION_REV1 , GEOIP_STANDARD );
+
+opens the database file in the standard location for GeoIP City, typically
+I</usr/local/share/GeoIP/GeoIPCity.dat>.
+
 =back
 
 =head1 OBJECT METHODS
@@ -149,7 +175,7 @@ http://sourceforge.net/projects/geoip/
 
 =head1 VERSION
 
-1.25
+1.27
 
 =head1 SEE ALSO
 
@@ -157,7 +183,7 @@ Geo::IP::Record
 
 =head1 AUTHOR
 
-Copyright (c) 2004, MaxMind LLC
+Copyright (c) 2005, MaxMind LLC
 
 All rights reserved.  This package is free software; you can redistribute it
 and/or modify it under the same terms as Perl itself.
